#
# spec file for package atftp
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#
#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%define _fwdefdir %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services
%define pkg_version 0.7
Name:           atftp
Version:        0.7.0
Release:        169.2
Summary:        Advanced TFTP Server and Client
License:        GPL-2.0+
Group:          System/Daemons
Url:            ftp://ftp.mamalinux.com/pub/atftp/
Source:         %{name}-%{pkg_version}.tar.bz2
Source1:        atftpd.init
Source2:        atftpd.sysconfig
Source3:        atftpd.logrotate
Source4:        atftp.fw
Source5:        atftpd.service
Source6:        atftpd.socket
Patch1:         atftp-0.7.dif
Patch2:         atftp-CLK_TCK.diff
Patch3:         atftp-0.7_compiler_warnings.patch
Patch4:         atftp-0.7_thread_crash.patch
Patch5:         atftp-0.7_sol_ip.patch
Patch6:         atftp-0.7_bug-213384_OPT_NUMBER.patch
Patch7:         atftpd-0.7_unprotected_assignments_crash.patch
Patch8:         atftpd-0.7_circumvent_tftp_size_restrictions.patch
# PATCH-FIX-SUSE sorcerer's apprentice syndrom (bnc#727843)
Patch9:         atftp-0.7-sorcerers_apprentice.patch
# PATCH-FIX-SUSE server receive thread race (bnc#599856)
Patch10:        atftp-0.7-server_receive_race.patch
# PATCH-FIX-SUSE drop one duplicated ACK each round (bnc#774376)
Patch12:        atftp-0.7-ack_heuristic.patch
Patch13:        atftp-0.7-default_user_man.patch
# PATCH-FIX-SUSE update default directory in man (bnc#507011)
Patch14:        atftp-0.7-default_dir_man.patch
Patch15:        atftp-drop_privileges_non-daemon.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  pcre-devel
BuildRequires:  readline-devel
BuildRequires:  tcpd-devel
Requires(pre):  %fillup_prereq
Requires(pre):  pwdutils
Recommends:     logrotate
Conflicts:      tftp
Provides:       tftp(client)
Provides:       tftp(server)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} >= 1210
BuildRequires:  systemd-rpm-macros
%{?systemd_requires}
%else
Requires(pre):	%insserv_prereq
%endif

%description
atftp stands for Advanced Trivial File Transfer Protocol. It is called
"advanced", in contrast to others TFTP servers, for two reasons. First,
it is intended to be fully compliant with all related RFCs. This
includes RFC1350, RFC2090, RFC2347, RFC2348, and RFC2349. Second, atftp
is intended for serving boot files to large clusters. It is
multithreaded and will eventually support multicast, allowing faster
boot of hundreds of machines simultaneously.

%prep
%setup -q -n %{name}-%{pkg_version}
%patch1
%patch2
%patch3
%patch4
%patch5
%patch6
%patch7
%patch8
%patch9
%patch10
%patch12
%patch13
%patch14
%patch15 -p1

%build
autoreconf -fi
CFLAGS="%optflags -fgnu89-inline"
%configure
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
# SuSE rc
%if 0%{?suse_version} >= 1210
install -D -m 0644 %{SOURCE5} %{buildroot}/%{_unitdir}/atftpd.service
install -D -m 0644 %{SOURCE6} %{buildroot}/%{_unitdir}/atftpd.socket
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcatftpd
%else
install -D -m 0755 %{SOURCE1} %{buildroot}%{_initddir}/atftpd
ln -s -f ../..%{_initddir}/atftpd %{buildroot}%{_sbindir}/rcatftpd
%endif
install -D -m 0644 %{SOURCE2} %{buildroot}%{_fillupdir}/sysconfig.atftpd
install -D -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
mkdir -p %{buildroot}/%{_fwdefdir}
install -m 0644 %{SOURCE4} %{buildroot}/%{_fwdefdir}/atftp
install -d -m 0755 %{buildroot}/srv/tftpboot
install -d -m 0750 %{buildroot}%{_localstatedir}/log/atftpd

%pre
# This group/user is shared with tftp, so please
# keep this in sync with tftp.spec
# add group
%{_sbindir}/groupadd -r tftp 2>/dev/null || :
# add user
%{_sbindir}/useradd -c "TFTP account" -d /srv/tftpboot -G tftp -g tftp \
  -r -s /bin/false tftp 2>/dev/null || :
# fix sysconfig to get new defaults on Update
if [ -f %{_sysconfdir}/sysconfig/atftpd ]; then
  sed -i -e "s@^\(ATFTPD_OPTIONS=\"--daemon \"\)@#\1@" %{_sysconfdir}/sysconfig/atftpd
  sed -i -e "s@^\(ATFTPD_DIRECTORY=\"/tftpboot\"\)@#\1@" %{_sysconfdir}/sysconfig/atftpd
fi
%if 0%{?suse_version} >= 1210
%service_add_pre atftpd.service atftpd.socket
%endif

%preun
%if 0%{?suse_version} >= 1210
%service_del_preun atftpd.service atftpd.socket
%else
%stop_on_removal atftpd
%endif

%post
%if 0%{?suse_version} >= 1210
%service_add_post atftpd.service atftpd.socket
%endif
%{fillup_only -n atftpd}

%postun
%if 0%{?suse_version} >= 1210
%service_del_postun atftpd.service atftpd.socket
%else
%restart_on_update atftpd
%insserv_cleanup
%endif

%files
%defattr(-,root,root)
%doc BUGS FAQ LICENSE README README.MCAST README.PCRE TODO
%{_bindir}/atftp
%{_sbindir}/atftpd
%{_sbindir}/in.tftpd
%{_sbindir}/rcatftpd
%if 0%{?suse_version} >= 1210
%{_unitdir}/atftpd.service
%{_unitdir}/atftpd.socket
%else
%{_initddir}/atftpd
%endif
%config %{_sysconfdir}/logrotate.d/%{name}
%{_fillupdir}/sysconfig.atftpd
%{_mandir}/man1/atftp.1.gz
%{_mandir}/man8/atftpd.8.gz
%{_mandir}/man8/in.tftpd.8.gz

%config %{_fwdefdir}/atftp
%dir %attr(0755,tftp,tftp) /srv/tftpboot
%dir %attr(0750,tftp,tftp) %{_localstatedir}/log/atftpd/

%changelog
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Fri Sep  8 2017 pmonrealgonzalez@suse.com
- Changed permissions of /srv/tftpboot to be readable [bsc#940608]
* Tue Dec  6 2016 vcizek@suse.com
- honor --user and --group options in non-daemon mode (bsc#1013565)
  * add atftp-drop_privileges_non-daemon.patch
* Mon Jun 15 2015 mpluskal@suse.com
- Use ATFTPD_BIND_ADDRESSES in init script (boo#921219)
- Move autoreconf back to %%buils as it causes issues with quilt
* Mon Jun  8 2015 schwab@suse.de
- Force gnu89 inline semantics
* Tue May 26 2015 mpluskal@suse.com
- Move autoreconf to %%prep section as it better fits there
* Sun May 24 2015 mpluskal@suse.com
- Fix atftpd.socket (boo#932161)
* Wed Mar 18 2015 mpluskal@suse.com
- Do not install service and socket file as executable
  * change to 0644
- Cleanup spec file with spec-cleaner
* Mon Feb 16 2015 p.drouand@gmail.com
- Add systemd support for openSUSE >= 12.1
* Tue Nov 12 2013 chris@computersalat.de
- rebase patches (p0)
- rename atftpd.init.d to atftpd.init
- fix spec
  * remove ghost /var/run/atftp (created by init)
* Thu Feb  7 2013 vcizek@suse.com
- create capabilites provided by both tftp and atftp
  (bnc#801481 or bnc#725378)
* Thu Jan  3 2013 vcizek@suse.com
- change ownership of /srv/tftpboot, because atftpd running as
  tftp:tftp can't write to that directory
- create pid directory on service start
- manpage changes:
  * substitute /tftpboot with /srv/tftpboot
  * default user is now tftp:tftp
  * added patches:
    atftp-0.7-default_user_man.patch
    atftp-0.7-default_dir_man.patch
* Mon Oct  8 2012 vcizek@suse.com
- use Vladimir Nadvornik's heuristic for packet retransmission
  by default (see bnc#774376)
  The RFC1350 compliant behaviour stays optional.
  (added atftp-0.7-ack_heuristic.patch)
- merged the two sorcerer's apprentice syndrome patches to one
  (removed atftp-0.7-prevent-sas.patch)
* Tue Sep 11 2012 vcizek@suse.com
- added rules for SuSEfirewall2 (bnc#729793)
* Tue Sep 11 2012 vcizek@suse.com
- use the "su" logrotate directive (bnc#677335)
* Wed Sep  5 2012 vcizek@suse.com
- prevent the sorcerer's apprentice syndrome situation only when
  explicitly specified by the user (bnc#774376)
  (added a new command line option --prevent-sas to turn it on)
* Wed Jan 11 2012 vcizek@suse.com
- fix a race condition where two server threads pick up a single
  client, which causes the transported file being overwritten
  (bnc#599856)
* Mon Jan  2 2012 vcizek@suse.cz
- added autoconf as BuildRequires
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Wed Nov  9 2011 vcizek@suse.com
- licence in spdx format
* Thu Nov  3 2011 vcizek@suse.com
- fixed the "Sorcerer's Apprentice Syndrome" bug
  (bnc#727843)
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Tue Sep  6 2011 vcizek@suse.com
- added missing PreReq: pwdutils (bnc#683140)
* Fri Oct 29 2010 chris@computersalat.de
- cleanup spec
  o RPM_BUILD_ROOT vs buildroot
- fix pre
  o no check before addding group/user (darix)
- fix files
  o provide /srv/tftpboot
- modify sysconfig
  o provide defaults (darix)
* Wed Oct 13 2010 chris@computersalat.de
- modified init/sysconfig file
  o set defaults in init file
- added default group/user tftp:tftp (bnc#472282)
- added /srv/tftpboot as default ATFTPD_DIRECTORY (bnc#248008,507011)
- added logrotate script
  o --logfile /var/log/atftpd/atftp.log
- added missing README.MCAST, README.PCRE
- some rpmlint stuff
  o fixed missing-dependency-to-logrotate
  o fixed init non-remote_fs-dependency
  o fixed init no-reload-entry
  o fixed non-conffile-in-etc
* Wed Sep 22 2010 cristian.rodriguez@opensuse.org
- add missing pcre-devel to build Requires (bnc#537425)
* Fri Sep 12 2008 mrueckert@suse.de
- add atftpd-0.7_circumvent_tftp_size_restrictions.patch:
  allow block counts higher than 65536 (Fate#303031)
- replace network with remote_fs in the init script dependencies
* Fri Aug 22 2008 ro@suse.de
- change fillup_and_insserv to fillup_only (not active by default)
* Thu Apr  3 2008 mrueckert@suse.de
- added atftpd-0.7_unprotected_assignments_crash.patch: (bnc#291884)
  under high load atftpd dies as data access wasnt always protected
  with a mutex.
* Thu Jun 21 2007 adrian@suse.de
- fix changelog entry order
* Mon Jan 22 2007 mrueckert@suse.de
- added atftp-0.7_bug-213384_OPT_NUMBER.patch:
  "atftpd incorrectly sends OACK (option acknowledge) packets"
  (#213384,#80441)
* Mon Jul 31 2006 mrueckert@suse.de
- added /var/run/atftpd/ (0755,nobody,nogroup):
  at ftp can finally create pid files
  the default pid file for a single instance will be
  /var/run/atftpd/pid
- added support to run multiple instances of atftpd bound to specific
  IP addresses:
  * new sysconfig variable ATFTPD_BIND_ADDRESSES: whitespace
    seperated list of ip addresses.
  * each instance has its own pid file /var/run/atftpd/$ip.pid
* Sat Jul  1 2006 mrueckert@suse.de
- bump the version number to 0.7.0:
  This fix is needed because 0.7 < 0.7cvs. Replaced %%{version}
  with %%{pkg_version} everywhere. %%{pkg_version} holds the original
  value of 0.7.
* Thu Mar 30 2006 mrueckert@suse.de
- added atftp-0.7_compiler_warnings.patch:
  o missing include of pthread.h
  o make the the 1st parameter of tftp_mtftp_missed_packet
    unsigned int to fix a differ in signedness warning
  o configure overwrote the CFLAGS from the environment.
  o fixed logging of threadids
- added atftp-0.7_thread_crash.patch:
  fixes http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=271816
- added atftp-0.7_sol_ip.patch:
  only use the SOL_IP if it is defined
- updated atftp-0.7.dif:
  o really always run through the whole bitmap to find old holes.
    (bug #148779, #65660)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec 20 2005 ro@suse.de
- define CLK_TCK if not already done
* Thu Mar  3 2005 nashif@suse.de
- Applied patch from #65660: transfer breaks down if packets get
  dropped
* Thu Mar  3 2005 nashif@suse.de
- According to #65660 memory allocation issue not present anymore
* Sun Feb 13 2005 nashif@suse.de
- fixed segfault on x86_64
* Tue Nov 16 2004 ro@suse.de
- merge old changelog entries (after checking all fixes are here)
- removed also destdir.patch (included upstream)
* Fri Nov 12 2004 jhargado@suse.de
- Added a patch to fix a problem where if a client requests a file
  that doesn't exist, sometimes the daemon would exit without warning.
  The .7 version of atftp is needed in SLRS to allow HA functionality.
  This package is only included in the SLRS distribution.
* Sat Sep 11 2004 kukuk@suse.de
- Adjust to new glibc __THROW define
* Mon Apr 12 2004 nashif@suse.de
- update to 0.7 final
  - when called in batch mode, return right exit code if
    operation fails.
* Tue Mar  9 2004 ms@suse.de
- include timeout patch:
  We finally got a network trace with
  the ACKs included.  When the client fails the checksum, it stops acking
  the server.  This was occurring anywhere from the middle to the end of the
  730MB download.  It boils down to slower systems are taking to long to
  write the network data to the disk and in the meanwhile the tftp timeout
  value is incrementing and when it reaches 5 tftp timeouts, the clients
  gives up!!   Dan added code to reset the timeout counter when the client
  received another good packet.   With this fix, the clients, even slow
  clients never failed.   We think adding more memory to the slower clients
  made the problem worse because it took longer to write the memory cache
  out to the disk and caused more timeouts.    While trying to cause more
  timeouts on the clients (we paused the client in the middle of the
  download), we noticed the server code has the same timeout scheme so Dan
  also added this code to reset the timeout counter when good packets were
  received.    These fixes look solid, even under error conditions.
* Mon Mar  1 2004 nashif@suse.de
- Update to 0.7 cvs
* Thu Feb 19 2004 kukuk@suse.de
- Cleanup neededforbuild
* Wed Feb  4 2004 ms@suse.de
- according to Anas Nashif <nashif@suse.de> the current version
  0.6.2 includes the fix for bug (#27341). buffer overflow when a long
  filename is sent to the server
* Wed Feb  4 2004 ms@suse.de
- include version 0.6.2 to SLES8 includes important multicast
  fixes related to project Point-of-Sale (#34074)
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Aug 29 2003 nashif@suse.de
- Provide default tftp directory
* Fri Aug  1 2003 nashif@suse.de
- update to 0.6.2
- Fixes bug #27341
- Readded conflict to tftp
* Wed May 28 2003 nashif@suse.de
- Removed conflict to tftp
- added manpages as doc files
* Mon May 26 2003 lmuelle@suse.de
- Remove set -e from init script; exit with rc 5 if binary is not installed
* Wed Jan  1 2003 nashif@suse.de
- Fixed bug #22614: missing metadata in sysconfig template
* Sat Sep 14 2002 nashif@suse.de
- Added missing restart to init script
* Fri Aug 30 2002 nashif@suse.de
- Fixed bug #18661: Removed ; from sysconfig file
* Sat Aug 17 2002 nashif@suse.de
- Fixed bug #17793: Added PreReq
- Fixed init script output
* Sun Jun  9 2002 nashif@suse.de
- Update to version 0.6.1.1
* Sat Apr 13 2002 nashif@suse.de
- Use tftp_LDADD for libraries instead of LDFLAGS
* Sat Mar 23 2002 nashif@suse.de
- Initial release (0.50)
